#!/bin/sh

# All Rights Reserved * Licensed Materials - Property of IBM
# 5724-I63, 5724-H88, 5655-N01, 5733-W60 (C) COPYRIGHT International Business Machines Corp., 1997,2011
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# WebSphere Intelligent Management scripts to link two cells together for OVERLAY communication 

binDir=`dirname $0`
. $binDir/setupCmdLine.sh

if [ $# -ne 2 ] ; then
    echo "Usage: linkCells.sh <cell1Info> <cell2Info>"
    echo "   where both <cell1Info> and <cell2Info> are of one of the following two forms:"
    echo "     <dmgrHost>:<dmgrSoapPort>"
    echo "        if WebSphere security is NOT enabled in the cell"
    echo "     <dmgrHost>:<dmgrSoapPort>:<userName>:<password>[:<trustStoreName>]"
    echo "        if WebSphere security is enabled in the cell"
    echo "This script links two cells together for communication over the OVERLAY ports."
    exit 1
fi

HOST1=`echo $1 | cut -d: -f1`
PORT1=`echo $1 | cut -d: -f2`
UID1=`echo $1 | cut -d: -f3`
PWD1=`echo $1 | cut -d: -f4`
TS1=`echo $1 | cut -d: -f5`
TS1=${TS1:-CellDefaultTrustStore}

HOST2=`echo $2 | cut -d: -f1`
PORT2=`echo $2 | cut -d: -f2`
UID2=`echo $2 | cut -d: -f3`
PWD2=`echo $2 | cut -d: -f4`
TS2=`echo $2 | cut -d: -f5`
TS2=${TS2:-CellDefaultTrustStore}

PY="-f ${WAS_HOME}/bin/linkCells.py"

INVOKE1="${WAS_HOME}/bin/wsadmin.sh -conntype SOAP -host $HOST1 -port $PORT1 -user $UID1 -password $PWD1 ${PY}"
INVOKE2="${WAS_HOME}/bin/wsadmin.sh -conntype SOAP -host $HOST2 -port $PORT2 -user $UID2 -password $PWD2 ${PY}"

OVERLAY_FILE1=/tmp/_overlay1_$$
OVERLAY_FILE2=/tmp/_overlay2_$$

echo "Begin linking cells ..."

# Get the overlay config from cell1 and store in OVERLAY_FILE1
$INVOKE1 -getOverlay::${OVERLAY_FILE1}

# Get the overlay config from cell2 and store it in OVERLAY_FILE2
# Add the overlay config from cell1 to cell2
# If a password was provided for cell1, import cell1's signer certificate into cell2
if [ "$PWD1" != "" ]; then
   $INVOKE2 -getOverlay::${OVERLAY_FILE2} -addOverlay::${OVERLAY_FILE1} -importSigner:${HOST1}:${PORT1}:${TS1}
else
   $INVOKE2 -getOverlay::${OVERLAY_FILE2} -addOverlay::${OVERLAY_FILE1}
fi

# Add the overlay config from cell2 to cell1
# If a password was provided for cell2, import cell2's signer certificate into cell1
if [ "$PWD2" != "" ]; then
   $INVOKE1 -addOverlay::${OVERLAY_FILE2} -importSigner:${HOST2}:${PORT2}:${TS2}
else
   $INVOKE1 -addOverlay::${OVERLAY_FILE2}
fi

# Clean up temporary files
rm -f $OVERLAY_FILE1 $OVERLAY_FILE2

echo "Done linking cells."
